@@ -1,6 +1,7 @@
-package Pcore::DBD v0.3.3;
+package Pcore::DBD v0.3.4;
 
-use Pcore qw[-role];
+use Pcore -role;
+use Pcore::Util::Text qw[escape_scalar];
 use DBI;
 
 with qw[Pcore::Core::H::Role::Wrapper];
@@ -243,17 +244,15 @@ sub _default_attr {
         HandleError => sub {
             my $msg = shift;
 
-            P->text->escape_scalar($msg);
+            escape_scalar $msg;
 
-            Pcore::Core::Exception::Object->new_exception( $msg, level => 'ERROR', skip_frames => 1, trace => 1 )->propagate;
-
-            return 1;
+            die $msg;
         },
         ShowErrorStatement => 1,
         AutoCommit         => 1,
         Callbacks          => {
             connected => sub {
-                debug( 'Connected to: ' . $_[1] );
+                P->log->debug( 'Connected to: ' . $_[1] );
 
                 return;
             },
@@ -261,13 +260,13 @@ sub _default_attr {
                 return;
             },
             do => sub {
-                debug( 'Do: ' . $_[1] );
+                P->log->debug( 'Do: ' . $_[1] );
 
                 return;
             },
             ChildCallbacks => {
                 execute => sub {
-                    debug( 'Execute: ' . $_[0]->{Statement} );
+                    P->log->debug( 'Execute: ' . $_[0]->{Statement} );
 
                     return;
                 }
@@ -346,9 +345,9 @@ sub ddl {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 112                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 113                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 235                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_default_attr' declared but not     │
+## │    3 │ 236                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_default_attr' declared but not     │
 ## │      │                      │ used                                                                                                           │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
